@@ -11,15 +11,9 @@ try:
 except ImportError:
     from urlparse import parse_qsl
 
-from miss.identity import getattrsi
 from miss.six import PY3
 
 
-def text(o, *attrs):
-    attrs += ('text',)
-    return getattrsi(o, *attrs)
-
-
 if PY3:
     def urldecode(s):
         if isinstance(s, bytes):
